#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 warp
version:              3.3.16
visibility:           public
id:                   warp-3.3.16-JCGQXtllRgYC0aGKpmQh8V
key:                  warp-3.3.16-JCGQXtllRgYC0aGKpmQh8V
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  2418613fa25d3dad1d4d363250b0240a
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Recv
    Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-8.10.5/site-local/warp-3.3.16
library-dirs:         /usr/lib/ghc-8.10.5/site-local/warp-3.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/warp-3.3.16
hs-libraries:         HSwarp-3.3.16-JCGQXtllRgYC0aGKpmQh8V
depends:
    array-0.5.4.0 auto-update-0.1.6-7K4JToCmNkHJlkSexgjzA2
    base-4.14.2.0 bsb-http-chunked-0.0.0.4-8SOvas9224TGJ1RVUKFyLj
    bytestring-0.10.12.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB containers-0.6.4.1
    ghc-prim-0.6.1 hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE
    http-date-0.0.11-HIzXdVNetB5z6T1SnAv7U
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB
    http2-3.0.2-4MFc8lpSzy29t1ReDOKVbF
    iproute-1.7.11-d5s0fig5u67LjOGRvUkdk
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M
    simple-sendfile-0.2.30-LNLp4YabLPWI8QmtIJmgZU stm-2.5.0.1
    streaming-commons-0.2.2.1-C8lvasNXOGTK9YCgFpiJpk text-1.2.4.1
    time-manager-0.0.0-2aL2dOmRsab7SGaPB4emnM unix-2.7.2.2
    unix-compat-0.5.3-1KqjYp6svTH6EdzCzH8QEz
    unliftio-0.2.18-5P4UivtPmWZvk4Y5NpZt0
    vault-0.3.1.5-2u0dJePH52AL9bdJMWCcCZ
    wai-3.2.3-6NrdunSiuKK6vnccK2cwty word8-0.1.3-C9wcaZKtRvf9CTebSJFNpx
    x509-1.7.5-FcakXsO5AZG8CA3iSGWvZR

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

